@@ -120,8 +120,4 @@ def load_predictionData(save_fd):
     predictions_data = torch.load(os.path.join(save_fd, 'predictions_data.dataset'))
     return predictions_data
 
-if __name__ == "__main__":
-    #safe_fd = "C:\\AsianGCN\\data\\sroie\\processed"
-    #get_data(source_fd="C:\\AsianGCN\\raw\\box", save_fd=safe_fd, export=False)
-    getDataForUniquePrediction(source_fd="C:\\AsianGCN\\prediction\\raw\\box",
-                               save_fd="C:\\AsianGCN\\prediction\\processed", export=False)
+
